﻿using System;
using System.Windows.Forms;
using System.Collections;
using System.Diagnostics;
using System.IO;
using PdfSharp.Drawing;
using PdfSharp.Pdf;
using PdfSharp.Pdf.IO;

namespace Test
{
    public partial class Form1 : Form
    {
        string appPath = "";
        
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            appPath = Path.GetDirectoryName(Application.ExecutablePath);
            if (appPath.IndexOf("bin") != -1) //Debugging
            {
                appPath = appPath.Substring(0, appPath.IndexOf("bin"));
            }
            
            ArrayList files = new ArrayList();
            files.Add(appPath + @"Test Files\File 1.pdf");
            files.Add(appPath + @"Test Files\File 2.pdf");
            files.Add(appPath + @"Test Files\File 3.pdf");

            string filename1 = "";
            foreach (string file in files)
            {
                if (filename1 == "")
                {
                    filename1 = file;
                    continue;
                }

                CombinePdfFiles(filename1, file);
                Debug.WriteLine("Added " + file + " to " + filename1);
            }

            //Open
            Process.Start(filename1);
        }

        private void CombinePdfFiles(string filename1, string filename2)
        {
            if (!File.Exists(filename1) || !File.Exists(filename2))
            {
                return;
            }

            // Open the input files
            PdfDocument inputDocument1 = PdfReader.Open(filename1, PdfDocumentOpenMode.Import);
            PdfDocument inputDocument2 = PdfReader.Open(filename2, PdfDocumentOpenMode.Import);

            // Create the output document
            PdfDocument outputDocument = new PdfDocument();

            outputDocument.PageLayout = PdfPageLayout.SinglePage;

            XFont font = new XFont("Verdana", 10, XFontStyle.Bold);
            XStringFormat format = new XStringFormat();
            format.Alignment = XStringAlignment.Center;
            format.LineAlignment = XLineAlignment.Far;
            XGraphics gfx;
            XRect box;
            int count = Math.Max(inputDocument1.PageCount, inputDocument2.PageCount);
            for (int idx = 0; idx < count; idx++)
            {
                // Get page from 1st document
                PdfPage page1 = inputDocument1.PageCount > idx ?
                  inputDocument1.Pages[idx] : new PdfPage();

                // Get page from 2nd document
                PdfPage page2 = inputDocument2.PageCount > idx ?
                  inputDocument2.Pages[idx] : new PdfPage();

                // Add both pages to the output document
                page1 = outputDocument.AddPage(page1);
                page2 = outputDocument.AddPage(page2);

                // Write document file name and page number on each page
                gfx = XGraphics.FromPdfPage(page1);
                box = page1.MediaBox.ToXRect();
                box.Inflate(0, -10);
                gfx.DrawString(String.Format("{0} • {1}", filename1, idx + 1),
                  font, XBrushes.Red, box, format);

                gfx = XGraphics.FromPdfPage(page2);
                box = page2.MediaBox.ToXRect();
                box.Inflate(0, -10);
                gfx.DrawString(String.Format("{0} • {1}", filename2, idx + 1),
                  font, XBrushes.Red, box, format);
            }

            outputDocument.Save(filename1);
        }
    }
}
